% fig4.m
% 
% Generates a figure with histograms of ice volume relative to 2005 AD on top 
% and points with error bars below.  The points with error bars show the effects 
% of different weighting stringencies on the estimated uncertainty.  

clear all
close all

% Boxes for relevant time slices from Alley et al., QSR, 2010.  
alley_box = [-1.0, -3.5, -5.0; 
		   11.0, 3.0, 2.0; 
		   0.0, -0.5, -1.0]; 

times = [-115, -20, -5, 1840, 2100, 2300, 3000]; 

y_bounds = [-6, 0; -1, 9; 0, 2.5; 0, 0.1; -0.16, 0; -1, 0; -3.5, 0]; 

% Read in the data.  Note that row 1 gives the results from Ralf's runs.  
data = dlmread('data_table_2.csv'); 
raw_vols = data(1: 101, 7: 14); 
		% simulated ice volumes at different times, in m sle
yn = data(1: 101, 15: 18); 
		% whether or not the simulated volumes in 2005 AD lie within specified 
		% distances of the expected value

% Use the raw_vols matrix to find the differences between 2005 AD and the values 
% in each column.  
for i = 1: 1: numel(raw_vols(1, :)); 
	diffs(:, i) = raw_vols(:, i).- raw_vols(:, 5); 
end
diffs(:, 5) = []; 

% Find the bin positions and the y-axis limits for the histograms.  
x = linspace(floor(min(min(diffs))), ceil(max(max(diffs))), 40); 
y_limits = [min(x)- 0.5 max(x)+ 0.5]; 

for i = 1: 1: 7; 
	
	% Plot all the runs in gray.  
	subplot(2, 7, i)
	[n_all, x_all] = hist(diffs(2: 101, i), x); 
% 	x_all(n_all == 0) = []; 
% 	n_all(n_all == 0) = []; 
	barh(x_all, n_all, 0.8, 'facecolor', [0.6 0.6 0.6], 'edgecolor', [0.6 0.6 0.6]); 
	set(gca, 'ylim', y_limits); 
	set(gca, 'xlim', [0 ceil(1.3* max(n_all))])
	x_limits = get(gca, 'xlim'); 
	x_ticks = [x_limits(1), x_limits(1)+ (x_limits(2)- x_limits(1))/ 3, x_limits(2)- (x_limits(2)- x_limits(1))/ 3, x_limits(2)]; 
	hold on
	
	% Plot the runs that meet the 10% criterion in blue on top of the gray 
	% histograms.  
	sub_diffs = diffs(2: 101, i); 
	sub_diffs(yn(2: 101, 2) ~= 1) = []; 
	[n_all, x_all] = hist(sub_diffs, x); 
% 	x_all(n_all == 0) = []; 
% 	n_all(n_all == 0) = []; 
	barh(x_all, n_all, 0.8, 'facecolor', [0 0 1], 'edgecolor', [0 0 1]); 
	
	% Plot Ralf's result on top as a red line.  
	plot(x_limits, [diffs(1, i) diffs(1, i)], 'r')
	
	% For the appropriate plots, show comparison to Richard's boxes.  
	if i < 4; 
		alley_x = 0.85* x_limits(2); 
		errorbar(alley_x, alley_box(i, 2), 0, 0, alley_box(i, 2)- alley_box(i, 1), alley_box(i, 3)- alley_box(i, 2), "~>"); 
		plot(alley_x, alley_box(i, 2), 'x', 'markersize', 3)
		plot(alley_x, alley_box(i, 1), '+', 'markersize', 3); 
		plot(alley_x, alley_box(i, 3), '+', 'markersize', 3); 
% 		for k = 1: 1: 3; 
% 			plot(x_limits, [alley_box(i, k) alley_box(i, k)], 'g')
% 			hold on
% 		end
	end
	
	% Make the upper row of plots look nice.  
	set(gca, 'xtick', x_ticks); 
	if i < 4; 
		title([num2str(times(i)) ' ka'])
	else
		title([num2str(times(i)) ' AD'])
	end
	plot([0 0], y_limits, 'k')
	
	% Make the lower row of plots.  
	subplot(2, 7, i+ 7)
	ebar = zeros(numel(yn(1, :))+ 1, 3); 
	ebar(1, 1: 3) = [median(diffs(:, i))- min(diffs(:, i)), median(diffs(:, i)), max(diffs(:, i))- median(diffs(:, i))]; 
	for j = 1: 1: numel(yn(1, :)); 
		sub_diffs = diffs(:, i); 
		sub_diffs(yn(:, j) ~= 1) = []; 
		ebar(j+ 1, 1: 3) = [median(sub_diffs)- min(sub_diffs), median(sub_diffs), max(sub_diffs)- median(sub_diffs)]; 
	end
	errorbar(1: 1: 5, ebar(:, 2), 0, 0, ebar(:, 1), ebar(:, 3), "~>"); 
	hold on
	plot(1: 1: 5, ebar(:, 2), 'x', 'markersize', 3)
	plot(1: 1: 5, ebar(:, 2)- ebar(:, 1), '+', 'markersize', 3); 
	plot(1: 1: 5, ebar(:, 2)+ ebar(:, 3), '+', 'markersize', 3); 
	set(gca, 'ylim', y_bounds(i, :)); 
	
end

subplot(2, 7, 13)
set(gca, 'ytick', [0: -0.25: -1.5])