clear all
close all
clc

% Set some values.  
num = 10^ 4; 
Gt2mm = 1/ 360; 
row_2000 = 6403; 
yr = [1955, 2010]; 

% Total mass balance (TMB) data from Rignot et al., 2008, Table 1
% Years 2005-2007 extend outside the time when our simulations are forced by
% real temperature data.  Columns 2 and 3 are in Gt/yr.  
mbal = [1958, -119, 68; 
	   1964, -106, 73; 
	   1996, -97, 47;
	   2000, -156, 44; 
	   2004, -231, 40;
	   2005, -293, 39;]; 
% 	   2006, -265, 39; 
% 	   2007, -267, 38;]; 

% Convert the second and third columns of mbal into mm sle/yr.  
mbal(:, 2: 3) = mbal(:, 2: 3)* Gt2mm; 

% /----- Calculate mass balances from model runs -----/

% Read in the results from the model simulations.  yn indicates whether 
% particular runs passed the within-10%-in-2005 test.  temp is the temperature 
% deviation for each year; time is a vector of years.  
data = dlmread('data_table_1.csv'); 
data2 = dlmread('data_table_2.csv'); 
yn = data2(2: 101, 16); 
temp = data(row_2000+ (yr(1)- 2000): row_2000+ (yr(2)- 2000), 2); 
time = [yr(1): 1: yr(2)]'; 
vol_2005 = data2(1: 101, 11); 

% Subset the data for convenience.  
sub1 = data(row_2000+ (yr(1)- 2000): row_2000+ (yr(2)- 2000), 4: 104); 
sub2 = data(row_2000+ (yr(1)- 2000- 1): row_2000+ (yr(2)- 2000- 1), 4: 104); 
% nrows = numel(sub_data(:, 1)); 

% Calculate the differences in mm sle/yr.  Note that the first column of diff 
% corresponds to Ralf's best run from his 2011 Annals paper.  
diff = sub1- sub2; 
diff = 1000* diff; 

% /----- Calculate mean mass balance and trend from Rignot et al. data -----/

% Initialize storage matrices for random realizations of data.  
avg = zeros(1, num); 
slope = zeros(1, num); 

% Using Monte Carlo, find the average mass balance and trend given the data in 
% the mbal matrix, with uncertainties.  
for i = 1: 1: num; 
	draw = normrnd(mbal(:, 2), mbal(:, 3)); 
	avg(i) = mean(draw); 
	fit = polyfit(mbal(:, 1), draw, 1); 
	slope(i) = fit(1); 
end
% Extract the parameters of the normal distributions describing the Monte Carlo 
% results.  
norm_avg = [mean(avg), std(avg)]; 
norm_slope = [mean(slope), std(slope)]; 

% /----- Extract the mean mass balance and trends from the model results -----/
avg_model = zeros(1, 101); 
slope_model = zeros(1, 101); 

rows = mbal(:, 1)- yr(1)+ 1; 
for i = 1: 1: 101; 
	avg_model(i) = mean(diff(rows, i)); 
	fit = polyfit(rows, diff(rows, i), 1); 
	slope_model(i) = fit(1); 
end

% /----- Plot the results.  -----/

figure
subplot(3, 2, 1: 2)
plot(time, temp, 'k'); 

subplot(3, 2, 3: 4)
for i = 2: 1: 101; 
	if yn(i- 1) ~= 1; 
		plot(time, diff(:, i), 'color', [0.6 0.6 0.6]); 
		hold on
	end
end
for i = 2: 1: 101; 
	if yn(i- 1) == 1; 
		plot(time, diff(:, i), 'b')
		hold on
	end
end
plot(time, diff(:, 1), 'r', 'LineWidth', 0.75)
errorbar(mbal(:, 1), mbal(:, 2), 2* mbal(:, 3)) % OBS! double errorbar heights
plot(mbal(:, 1), mbal(:, 2), 'k.')

x_avg = linspace(min(avg), max(avg), 50); 
y_avg = normpdf(x_avg, norm_avg(1), norm_avg(2)); 
x_slope = linspace(min(slope), max(slope), 50); 
y_slope = normpdf(x_slope, norm_slope(1), norm_slope(2)); 

subplot(3, 2, 5)
plot(x_avg, y_avg, 'k', 'LineWidth', 0.75)
hold on
ylim1 = get(gca, 'YLim'); 

subplot(3, 2, 6)
plot(x_slope, y_slope, 'k', 'LineWidth', 0.75)
hold on
ylim2 = get(gca, 'YLim'); 

for i = 2: 1: 101; 
	if yn(i- 1) ~= 1; 
		subplot(3, 2, 5)
		plot([avg_model(i) avg_model(i)], ylim1, 'color', [0.6 0.6 0.6])
		subplot(3, 2, 6)
		plot([slope_model(i) slope_model(i)], ylim2, 'color', [0.6 0.6 0.6])
	end
end

for i = 2: 1: 101; 
	if yn(i- 1) == 1; 
		subplot(3, 2, 5)
		plot([avg_model(i) avg_model(i)], ylim1, 'b', 'LineWidth', 0.75)
		subplot(3, 2, 6)
		plot([slope_model(i) slope_model(i)], ylim2, 'b', 'LineWidth', 0.75)
	end
end

subplot(3, 2, 5)
plot([avg_model(1) avg_model(1)], ylim1, 'r', 'LineWidth', 0.75)
subplot(3, 2, 6)
plot([slope_model(1) slope_model(1)], ylim2, 'r', 'LineWidth', 0.75)

% Make the plots look nice.  
subplot(3, 2, 1: 2)
xlabel('Time (years AD)')
ylabel('T. anomaly (deg. C)')
axis(yr)
set(gca, 'xtick', yr(1): 5: yr(2)); 
subplot(3, 2, 3: 4)
xlabel('Time (years AD)')
ylabel('Mass bal. (mm sle/yr)')
axis(yr)
set(gca, 'xtick', yr(1): 5: yr(2)); 
plot(yr, [0 0], 'k--')
subplot(3, 2, 5)
xlabel('Mean mass balance (mm sle/yr)')
ylabel('Prob. density')
axis([-1.5 0 0 7])
set(gca, 'xtick', [-1.5: 0.25: 0])
subplot(3, 2, 6)
xlabel('Mass balance trend (mm sle/yr2)')
ylabel('Prob. density')
axis([-0.02 0.005 0 120])

figure
subplot(2, 2, 1)
plot(avg_model, slope_model, '+')
xlabel('Average mass balance')
ylabel('Slope of mass bal. trend')
axis square

subplot(2, 2, 2)
plot(vol_2005, slope_model, '+')
xlabel('Volume in 2005')
ylabel('Slope of mass bal. trend')
axis square

subplot(2, 2, 3)
plot(avg_model, vol_2005, '+')
xlabel('Average mass balance')
ylabel('Volume in 2005')
axis square